summaryrefslogtreecommitdiffstats
path: root/kdejava/koala/org/kde/koala/KEditListBox.java
diff options
context:
space:
mode:
Diffstat (limited to 'kdejava/koala/org/kde/koala/KEditListBox.java')
-rw-r--r--kdejava/koala/org/kde/koala/KEditListBox.java106
1 files changed, 53 insertions, 53 deletions
diff --git a/kdejava/koala/org/kde/koala/KEditListBox.java b/kdejava/koala/org/kde/koala/KEditListBox.java
index ed816112..26377d58 100644
--- a/kdejava/koala/org/kde/koala/KEditListBox.java
+++ b/kdejava/koala/org/kde/koala/KEditListBox.java
@@ -2,13 +2,13 @@
package org.kde.koala;
import org.kde.qt.Qt;
-import org.kde.qt.QListBox;
-import org.kde.qt.QMetaObject;
+import org.kde.qt.TQListBox;
+import org.kde.qt.TQMetaObject;
import org.kde.qt.QtSupport;
import java.util.ArrayList;
-import org.kde.qt.QPushButton;
-import org.kde.qt.QWidget;
-import org.kde.qt.QGroupBox;
+import org.kde.qt.TQPushButton;
+import org.kde.qt.TQWidget;
+import org.kde.qt.TQGroupBox;
/**
@@ -22,7 +22,7 @@ import org.kde.qt.QGroupBox;
@short An editable listbox
*/
-public class KEditListBox extends QGroupBox {
+public class KEditListBox extends TQGroupBox {
protected KEditListBox(Class dummy){super((Class) null);}
/**
@@ -36,7 +36,7 @@ public class KEditListBox extends QGroupBox {
public static final int All = Add|Remove|UpDown;
- public native QMetaObject metaObject();
+ public native TQMetaObject metaObject();
public native String className();
/**
Create an editable listbox.
@@ -50,26 +50,26 @@ public class KEditListBox extends QGroupBox {
possible to enter items twice into the listbox.
@short Create an editable listbox.
*/
- public KEditListBox(QWidget parent, String name, boolean checkAtEntering, int buttons) {
+ public KEditListBox(TQWidget parent, String name, boolean checkAtEntering, int buttons) {
super((Class) null);
newKEditListBox(parent,name,checkAtEntering,buttons);
}
- private native void newKEditListBox(QWidget parent, String name, boolean checkAtEntering, int buttons);
- public KEditListBox(QWidget parent, String name, boolean checkAtEntering) {
+ private native void newKEditListBox(TQWidget parent, String name, boolean checkAtEntering, int buttons);
+ public KEditListBox(TQWidget parent, String name, boolean checkAtEntering) {
super((Class) null);
newKEditListBox(parent,name,checkAtEntering);
}
- private native void newKEditListBox(QWidget parent, String name, boolean checkAtEntering);
- public KEditListBox(QWidget parent, String name) {
+ private native void newKEditListBox(TQWidget parent, String name, boolean checkAtEntering);
+ public KEditListBox(TQWidget parent, String name) {
super((Class) null);
newKEditListBox(parent,name);
}
- private native void newKEditListBox(QWidget parent, String name);
- public KEditListBox(QWidget parent) {
+ private native void newKEditListBox(TQWidget parent, String name);
+ public KEditListBox(TQWidget parent) {
super((Class) null);
newKEditListBox(parent);
}
- private native void newKEditListBox(QWidget parent);
+ private native void newKEditListBox(TQWidget parent);
public KEditListBox() {
super((Class) null);
newKEditListBox();
@@ -81,26 +81,26 @@ public class KEditListBox extends QGroupBox {
<code>title</code>, which will be the title of the frame around the listbox.
@short Create an editable listbox.
*/
- public KEditListBox(String title, QWidget parent, String name, boolean checkAtEntering, int buttons) {
+ public KEditListBox(String title, TQWidget parent, String name, boolean checkAtEntering, int buttons) {
super((Class) null);
newKEditListBox(title,parent,name,checkAtEntering,buttons);
}
- private native void newKEditListBox(String title, QWidget parent, String name, boolean checkAtEntering, int buttons);
- public KEditListBox(String title, QWidget parent, String name, boolean checkAtEntering) {
+ private native void newKEditListBox(String title, TQWidget parent, String name, boolean checkAtEntering, int buttons);
+ public KEditListBox(String title, TQWidget parent, String name, boolean checkAtEntering) {
super((Class) null);
newKEditListBox(title,parent,name,checkAtEntering);
}
- private native void newKEditListBox(String title, QWidget parent, String name, boolean checkAtEntering);
- public KEditListBox(String title, QWidget parent, String name) {
+ private native void newKEditListBox(String title, TQWidget parent, String name, boolean checkAtEntering);
+ public KEditListBox(String title, TQWidget parent, String name) {
super((Class) null);
newKEditListBox(title,parent,name);
}
- private native void newKEditListBox(String title, QWidget parent, String name);
- public KEditListBox(String title, QWidget parent) {
+ private native void newKEditListBox(String title, TQWidget parent, String name);
+ public KEditListBox(String title, TQWidget parent) {
super((Class) null);
newKEditListBox(title,parent);
}
- private native void newKEditListBox(String title, QWidget parent);
+ private native void newKEditListBox(String title, TQWidget parent);
public KEditListBox(String title) {
super((Class) null);
newKEditListBox(title);
@@ -117,66 +117,66 @@ public class KEditListBox extends QGroupBox {
@short Another constructor, which allows to use a custom editing widget instead of the standard KLineEdit widget.
@see KURLRequester#customEditor
*/
// KEditListBox* KEditListBox(const QString& arg1,const KEditListBox::CustomEditor& arg2,QWidget* arg3,const char* arg4,bool arg5,int arg6); >>>> NOT CONVERTED
// KEditListBox* KEditListBox(const QString& arg1,const KEditListBox::CustomEditor& arg2,QWidget* arg3,const char* arg4,bool arg5); >>>> NOT CONVERTED
// KEditListBox* KEditListBox(const QString& arg1,const KEditListBox::CustomEditor& arg2,QWidget* arg3,const char* arg4); >>>> NOT CONVERTED
// KEditListBox* KEditListBox(const QString& arg1,const KEditListBox::CustomEditor& arg2,QWidget* arg3); >>>> NOT CONVERTED
// KEditListBox* KEditListBox(const QString& arg1,const KEditListBox::CustomEditor& arg2); >>>> NOT CONVERTED
/**
- Return a pointer to the embedded QListBox.
- @short Return a pointer to the embedded QListBox.
+ Return a pointer to the embedded TQListBox.
+ @short Return a pointer to the embedded TQListBox.
*/
- public native QListBox listBox();
+ public native TQListBox listBox();
/**
- Return a pointer to the embedded QLineEdit.
- @short Return a pointer to the embedded QLineEdit.
+ Return a pointer to the embedded TQLineEdit.
+ @short Return a pointer to the embedded TQLineEdit.
*/
public native KLineEdit lineEdit();
/**
Return a pointer to the Add button
@short Return a pointer to the Add button
*/
- public native QPushButton addButton();
+ public native TQPushButton addButton();
/**
Return a pointer to the Remove button
@short Return a pointer to the Remove button
*/
- public native QPushButton removeButton();
+ public native TQPushButton removeButton();
/**
Return a pointer to the Up button
@short Return a pointer to the Up button
*/
- public native QPushButton upButton();
+ public native TQPushButton upButton();
/**
Return a pointer to the Down button
@short Return a pointer to the Down button
*/
- public native QPushButton downButton();
+ public native TQPushButton downButton();
/**
- See QListBox.count()
- @short See QListBox.count()
+ See TQListBox.count()
+ @short See TQListBox.count()
*/
public native int count();
/**
- See QListBox.insertStringList()
- @short See QListBox.insertStringList()
+ See TQListBox.insertStringList()
+ @short See TQListBox.insertStringList()
*/
public native void insertStringList(String[] list, int index);
public native void insertStringList(String[] list);
/**
- See QListBox.insertStringList()
- @short See QListBox.insertStringList()
+ See TQListBox.insertStringList()
+ @short See TQListBox.insertStringList()
*/
public native void insertStrList(String[] list, int index);
public native void insertStrList(String[] list);
/**
- See QListBox.insertStrList()
- @short See QListBox.insertStrList()
+ See TQListBox.insertStrList()
+ @short See TQListBox.insertStrList()
*/
public native void insertStrList(String[] list, int numStrings, int index);
/**
- See QListBox.insertItem()
- @short See QListBox.insertItem()
+ See TQListBox.insertItem()
+ @short See TQListBox.insertItem()
*/
public native void insertItem(String text, int index);
public native void insertItem(String text);
@@ -186,18 +186,18 @@ public class KEditListBox extends QGroupBox {
*/
public native void clear();
/**
- See QListBox.text()
- @short See QListBox.text()
+ See TQListBox.text()
+ @short See TQListBox.text()
*/
public native String text(int index);
/**
- See QListBox.currentItem()
- @short See QListBox.currentItem()
+ See TQListBox.currentItem()
+ @short See TQListBox.currentItem()
*/
public native int currentItem();
/**
- See QListBox.currentText()
- @short See QListBox.currentText()
+ See TQListBox.currentText()
+ @short See TQListBox.currentText()
*/
public native String currentText();
/**
@@ -117,66 +117,66 @@ public class KEditListBox extends QGroupBox {
*/
- // KEditListBox* KEditListBox(const QString& arg1,const KEditListBox::CustomEditor& arg2,QWidget* arg3,const char* arg4,bool arg5,int arg6); >>>> NOT CONVERTED
- // KEditListBox* KEditListBox(const QString& arg1,const KEditListBox::CustomEditor& arg2,QWidget* arg3,const char* arg4,bool arg5); >>>> NOT CONVERTED
- // KEditListBox* KEditListBox(const QString& arg1,const KEditListBox::CustomEditor& arg2,QWidget* arg3,const char* arg4); >>>> NOT CONVERTED
- // KEditListBox* KEditListBox(const QString& arg1,const KEditListBox::CustomEditor& arg2,QWidget* arg3); >>>> NOT CONVERTED
- // KEditListBox* KEditListBox(const QString& arg1,const KEditListBox::CustomEditor& arg2); >>>> NOT CONVERTED
+ // KEditListBox* KEditListBox(const TQString& arg1,const KEditListBox::CustomEditor& arg2,TQWidget* arg3,const char* arg4,bool arg5,int arg6); >>>> NOT CONVERTED
+ // KEditListBox* KEditListBox(const TQString& arg1,const KEditListBox::CustomEditor& arg2,TQWidget* arg3,const char* arg4,bool arg5); >>>> NOT CONVERTED
+ // KEditListBox* KEditListBox(const TQString& arg1,const KEditListBox::CustomEditor& arg2,TQWidget* arg3,const char* arg4); >>>> NOT CONVERTED
+ // KEditListBox* KEditListBox(const TQString& arg1,const KEditListBox::CustomEditor& arg2,TQWidget* arg3); >>>> NOT CONVERTED
+ // KEditListBox* KEditListBox(const TQString& arg1,const KEditListBox::CustomEditor& arg2); >>>> NOT CONVERTED
/**